==> esp-idf-v5.0.3.zip: esp-idf-v5.0.3/components/openthread/openthread/src/core/utils/srp_client_buffers.cpp <==
/*
 *  Copyright (c) 2021, The OpenThread Authors.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of the copyright holder nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * @file
 *   This file implements the SRP client buffers and service pool.
 */

#include "srp_client_buffers.hpp"

#if OPENTHREAD_CONFIG_SRP_CLIENT_BUFFERS_ENABLE

#include <string.h>

#include "common/code_utils.hpp"
#include "common/instance.hpp"
#include "common/locator_getters.hpp"

namespace ot {
namespace Utils {

SrpClientBuffers::SrpClientBuffers(Instance &aInstance)
    : InstanceLocator(aInstance)
{
}

SrpClientBuffers::ServiceEntry *SrpClientBuffers::AllocateService(void)
{
    ServiceEntry *entry = mServicePool.Allocate();

    VerifyOrExit(entry != nullptr);

    entry->Clear();
    entry->mService.mName          = entry->mServiceName;
    entry->mService.mInstanceName  = entry->mInstanceName;
    entry->mService.mSubTypeLabels = entry->mSubTypeLabels;
    entry->mService.mTxtEntries    = &entry->mTxtEntry;
    entry->mService.mNumTxtEntries = 1;
    entry->mTxtEntry.mValue        = entry->mTxtBuffer;

exit:
    return entry;
}

} // namespace Utils
} // namespace ot

#endif // OPENTHREAD_CONFIG_SRP_CLIENT_BUFFERS_ENABLE

==> esp-idf-v5.1.7.zip: esp-idf-v5.1.7/components/openthread/openthread/src/core/utils/srp_client_buffers.cpp <==
/*
 *  Copyright (c) 2021, The OpenThread Authors.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of the copyright holder nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * @file
 *   This file implements the SRP client buffers and service pool.
 */

#include "srp_client_buffers.hpp"

#if OPENTHREAD_CONFIG_SRP_CLIENT_BUFFERS_ENABLE

#include "instance/instance.hpp"

namespace ot {
namespace Utils {

SrpClientBuffers::SrpClientBuffers(Instance &aInstance)
    : InstanceLocator(aInstance)
{
}

SrpClientBuffers::ServiceEntry *SrpClientBuffers::AllocateService(void)
{
    ServiceEntry *entry = mServicePool.Allocate();

    VerifyOrExit(entry != nullptr);

    entry->Clear();
    entry->mService.mName          = entry->mServiceName;
    entry->mService.mInstanceName  = entry->mInstanceName;
    entry->mService.mSubTypeLabels = entry->mSubTypeLabels;
    entry->mService.mTxtEntries    = &entry->mTxtEntry;
    entry->mService.mNumTxtEntries = 1;
    entry->mTxtEntry.mValue        = entry->mTxtBuffer;

exit:
    return entry;
}

} // namespace Utils
} // namespace ot

#endif // OPENTHREAD_CONFIG_SRP_CLIENT_BUFFERS_ENABLE
